@@ -19,6 +19,7 @@ Usage::
         DescribeClientVpnEndpointsPaginator,
         DescribeClientVpnRoutesPaginator,
         DescribeClientVpnTargetNetworksPaginator,
+        DescribeCoipPoolsPaginator,
         DescribeDhcpOptionsPaginator,
         DescribeEgressOnlyInternetGatewaysPaginator,
         DescribeExportImageTasksPaginator,
@@ -34,11 +35,19 @@ Usage::
         DescribeImportSnapshotTasksPaginator,
         DescribeInstanceCreditSpecificationsPaginator,
         DescribeInstanceStatusPaginator,
+        DescribeInstanceTypeOfferingsPaginator,
+        DescribeInstanceTypesPaginator,
         DescribeInstancesPaginator,
         DescribeInternetGatewaysPaginator,
         DescribeIpv6PoolsPaginator,
         DescribeLaunchTemplateVersionsPaginator,
         DescribeLaunchTemplatesPaginator,
+        DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsPaginator,
+        DescribeLocalGatewayRouteTableVpcAssociationsPaginator,
+        DescribeLocalGatewayRouteTablesPaginator,
+        DescribeLocalGatewayVirtualInterfaceGroupsPaginator,
+        DescribeLocalGatewayVirtualInterfacesPaginator,
+        DescribeLocalGatewaysPaginator,
         DescribeMovingAddressesPaginator,
         DescribeNatGatewaysPaginator,
         DescribeNetworkAclsPaginator,
@@ -65,6 +74,8 @@ Usage::
         DescribeTrafficMirrorSessionsPaginator,
         DescribeTrafficMirrorTargetsPaginator,
         DescribeTransitGatewayAttachmentsPaginator,
+        DescribeTransitGatewayMulticastDomainsPaginator,
+        DescribeTransitGatewayPeeringAttachmentsPaginator,
         DescribeTransitGatewayRouteTablesPaginator,
         DescribeTransitGatewayVpcAttachmentsPaginator,
         DescribeTransitGatewaysPaginator,
@@ -86,6 +97,7 @@ Usage::
         ExportTaskCompletedWaiter,
         GetAssociatedIpv6PoolCidrsPaginator,
         GetTransitGatewayAttachmentPropagationsPaginator,
+        GetTransitGatewayMulticastDomainAssociationsPaginator,
         GetTransitGatewayRouteTableAssociationsPaginator,
         GetTransitGatewayRouteTablePropagationsPaginator,
         ImageAvailableWaiter,
@@ -99,6 +111,8 @@ Usage::
         NatGatewayAvailableWaiter,
         NetworkInterfaceAvailableWaiter,
         PasswordDataAvailableWaiter,
+        SearchLocalGatewayRoutesPaginator,
+        SearchTransitGatewayMulticastGroupsPaginator,
         SecurityGroupExistsWaiter,
         ServiceResource,
         SnapshotCompletedWaiter,
@@ -165,6 +179,7 @@ Usage::
     describe_client_vpn_endpoints_paginator: DescribeClientVpnEndpointsPaginator = client.get_paginator("describe_client_vpn_endpoints")
     describe_client_vpn_routes_paginator: DescribeClientVpnRoutesPaginator = client.get_paginator("describe_client_vpn_routes")
     describe_client_vpn_target_networks_paginator: DescribeClientVpnTargetNetworksPaginator = client.get_paginator("describe_client_vpn_target_networks")
+    describe_coip_pools_paginator: DescribeCoipPoolsPaginator = client.get_paginator("describe_coip_pools")
     describe_dhcp_options_paginator: DescribeDhcpOptionsPaginator = client.get_paginator("describe_dhcp_options")
     describe_egress_only_internet_gateways_paginator: DescribeEgressOnlyInternetGatewaysPaginator = client.get_paginator("describe_egress_only_internet_gateways")
     describe_export_image_tasks_paginator: DescribeExportImageTasksPaginator = client.get_paginator("describe_export_image_tasks")
@@ -180,11 +195,19 @@ Usage::
     describe_import_snapshot_tasks_paginator: DescribeImportSnapshotTasksPaginator = client.get_paginator("describe_import_snapshot_tasks")
     describe_instance_credit_specifications_paginator: DescribeInstanceCreditSpecificationsPaginator = client.get_paginator("describe_instance_credit_specifications")
     describe_instance_status_paginator: DescribeInstanceStatusPaginator = client.get_paginator("describe_instance_status")
+    describe_instance_type_offerings_paginator: DescribeInstanceTypeOfferingsPaginator = client.get_paginator("describe_instance_type_offerings")
+    describe_instance_types_paginator: DescribeInstanceTypesPaginator = client.get_paginator("describe_instance_types")
     describe_instances_paginator: DescribeInstancesPaginator = client.get_paginator("describe_instances")
     describe_internet_gateways_paginator: DescribeInternetGatewaysPaginator = client.get_paginator("describe_internet_gateways")
     describe_ipv6_pools_paginator: DescribeIpv6PoolsPaginator = client.get_paginator("describe_ipv6_pools")
     describe_launch_template_versions_paginator: DescribeLaunchTemplateVersionsPaginator = client.get_paginator("describe_launch_template_versions")
     describe_launch_templates_paginator: DescribeLaunchTemplatesPaginator = client.get_paginator("describe_launch_templates")
+    describe_local_gateway_route_table_virtual_interface_group_associations_paginator: DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsPaginator = client.get_paginator("describe_local_gateway_route_table_virtual_interface_group_associations")
+    describe_local_gateway_route_table_vpc_associations_paginator: DescribeLocalGatewayRouteTableVpcAssociationsPaginator = client.get_paginator("describe_local_gateway_route_table_vpc_associations")
+    describe_local_gateway_route_tables_paginator: DescribeLocalGatewayRouteTablesPaginator = client.get_paginator("describe_local_gateway_route_tables")
+    describe_local_gateway_virtual_interface_groups_paginator: DescribeLocalGatewayVirtualInterfaceGroupsPaginator = client.get_paginator("describe_local_gateway_virtual_interface_groups")
+    describe_local_gateway_virtual_interfaces_paginator: DescribeLocalGatewayVirtualInterfacesPaginator = client.get_paginator("describe_local_gateway_virtual_interfaces")
+    describe_local_gateways_paginator: DescribeLocalGatewaysPaginator = client.get_paginator("describe_local_gateways")
     describe_moving_addresses_paginator: DescribeMovingAddressesPaginator = client.get_paginator("describe_moving_addresses")
     describe_nat_gateways_paginator: DescribeNatGatewaysPaginator = client.get_paginator("describe_nat_gateways")
     describe_network_acls_paginator: DescribeNetworkAclsPaginator = client.get_paginator("describe_network_acls")
@@ -211,6 +234,8 @@ Usage::
     describe_traffic_mirror_sessions_paginator: DescribeTrafficMirrorSessionsPaginator = client.get_paginator("describe_traffic_mirror_sessions")
     describe_traffic_mirror_targets_paginator: DescribeTrafficMirrorTargetsPaginator = client.get_paginator("describe_traffic_mirror_targets")
     describe_transit_gateway_attachments_paginator: DescribeTransitGatewayAttachmentsPaginator = client.get_paginator("describe_transit_gateway_attachments")
+    describe_transit_gateway_multicast_domains_paginator: DescribeTransitGatewayMulticastDomainsPaginator = client.get_paginator("describe_transit_gateway_multicast_domains")
+    describe_transit_gateway_peering_attachments_paginator: DescribeTransitGatewayPeeringAttachmentsPaginator = client.get_paginator("describe_transit_gateway_peering_attachments")
     describe_transit_gateway_route_tables_paginator: DescribeTransitGatewayRouteTablesPaginator = client.get_paginator("describe_transit_gateway_route_tables")
     describe_transit_gateway_vpc_attachments_paginator: DescribeTransitGatewayVpcAttachmentsPaginator = client.get_paginator("describe_transit_gateway_vpc_attachments")
     describe_transit_gateways_paginator: DescribeTransitGatewaysPaginator = client.get_paginator("describe_transit_gateways")
@@ -228,10 +253,13 @@ Usage::
     describe_vpcs_paginator: DescribeVpcsPaginator = client.get_paginator("describe_vpcs")
     get_associated_ipv6_pool_cidrs_paginator: GetAssociatedIpv6PoolCidrsPaginator = client.get_paginator("get_associated_ipv6_pool_cidrs")
     get_transit_gateway_attachment_propagations_paginator: GetTransitGatewayAttachmentPropagationsPaginator = client.get_paginator("get_transit_gateway_attachment_propagations")
+    get_transit_gateway_multicast_domain_associations_paginator: GetTransitGatewayMulticastDomainAssociationsPaginator = client.get_paginator("get_transit_gateway_multicast_domain_associations")
     get_transit_gateway_route_table_associations_paginator: GetTransitGatewayRouteTableAssociationsPaginator = client.get_paginator("get_transit_gateway_route_table_associations")
     get_transit_gateway_route_table_propagations_paginator: GetTransitGatewayRouteTablePropagationsPaginator = client.get_paginator("get_transit_gateway_route_table_propagations")
+    search_local_gateway_routes_paginator: SearchLocalGatewayRoutesPaginator = client.get_paginator("search_local_gateway_routes")
+    search_transit_gateway_multicast_groups_paginator: SearchTransitGatewayMulticastGroupsPaginator = client.get_paginator("search_transit_gateway_multicast_groups")
 """
-from mypy_boto3_ec2.client import EC2Client, EC2Client as Client
+from mypy_boto3_ec2.client import EC2Client as Client, EC2Client
 from mypy_boto3_ec2.paginator import (
     DescribeByoipCidrsPaginator,
     DescribeCapacityReservationsPaginator,
@@ -241,6 +269,7 @@ from mypy_boto3_ec2.paginator import (
     DescribeClientVpnEndpointsPaginator,
     DescribeClientVpnRoutesPaginator,
     DescribeClientVpnTargetNetworksPaginator,
+    DescribeCoipPoolsPaginator,
     DescribeDhcpOptionsPaginator,
     DescribeEgressOnlyInternetGatewaysPaginator,
     DescribeExportImageTasksPaginator,
@@ -256,11 +285,19 @@ from mypy_boto3_ec2.paginator import (
     DescribeImportSnapshotTasksPaginator,
     DescribeInstanceCreditSpecificationsPaginator,
     DescribeInstanceStatusPaginator,
+    DescribeInstanceTypeOfferingsPaginator,
+    DescribeInstanceTypesPaginator,
     DescribeInstancesPaginator,
     DescribeInternetGatewaysPaginator,
     DescribeIpv6PoolsPaginator,
     DescribeLaunchTemplateVersionsPaginator,
     DescribeLaunchTemplatesPaginator,
+    DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsPaginator,
+    DescribeLocalGatewayRouteTableVpcAssociationsPaginator,
+    DescribeLocalGatewayRouteTablesPaginator,
+    DescribeLocalGatewayVirtualInterfaceGroupsPaginator,
+    DescribeLocalGatewayVirtualInterfacesPaginator,
+    DescribeLocalGatewaysPaginator,
     DescribeMovingAddressesPaginator,
     DescribeNatGatewaysPaginator,
     DescribeNetworkAclsPaginator,
@@ -287,6 +324,8 @@ from mypy_boto3_ec2.paginator import (
     DescribeTrafficMirrorSessionsPaginator,
     DescribeTrafficMirrorTargetsPaginator,
     DescribeTransitGatewayAttachmentsPaginator,
+    DescribeTransitGatewayMulticastDomainsPaginator,
+    DescribeTransitGatewayPeeringAttachmentsPaginator,
     DescribeTransitGatewayRouteTablesPaginator,
     DescribeTransitGatewayVpcAttachmentsPaginator,
     DescribeTransitGatewaysPaginator,
@@ -304,12 +343,15 @@ from mypy_boto3_ec2.paginator import (
     DescribeVpcsPaginator,
     GetAssociatedIpv6PoolCidrsPaginator,
     GetTransitGatewayAttachmentPropagationsPaginator,
+    GetTransitGatewayMulticastDomainAssociationsPaginator,
     GetTransitGatewayRouteTableAssociationsPaginator,
     GetTransitGatewayRouteTablePropagationsPaginator,
+    SearchLocalGatewayRoutesPaginator,
+    SearchTransitGatewayMulticastGroupsPaginator,
 )
 from mypy_boto3_ec2.service_resource import (
-    EC2ServiceResource as ServiceResource,
     EC2ServiceResource,
+    EC2ServiceResource as ServiceResource,
 )
 from mypy_boto3_ec2.waiter import (
     BundleTaskCompleteWaiter,
@@ -362,6 +404,7 @@ __all__ = (
     "DescribeClientVpnEndpointsPaginator",
     "DescribeClientVpnRoutesPaginator",
     "DescribeClientVpnTargetNetworksPaginator",
+    "DescribeCoipPoolsPaginator",
     "DescribeDhcpOptionsPaginator",
     "DescribeEgressOnlyInternetGatewaysPaginator",
     "DescribeExportImageTasksPaginator",
@@ -377,11 +420,19 @@ __all__ = (
     "DescribeImportSnapshotTasksPaginator",
     "DescribeInstanceCreditSpecificationsPaginator",
     "DescribeInstanceStatusPaginator",
+    "DescribeInstanceTypeOfferingsPaginator",
+    "DescribeInstanceTypesPaginator",
     "DescribeInstancesPaginator",
     "DescribeInternetGatewaysPaginator",
     "DescribeIpv6PoolsPaginator",
     "DescribeLaunchTemplateVersionsPaginator",
     "DescribeLaunchTemplatesPaginator",
+    "DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsPaginator",
+    "DescribeLocalGatewayRouteTableVpcAssociationsPaginator",
+    "DescribeLocalGatewayRouteTablesPaginator",
+    "DescribeLocalGatewayVirtualInterfaceGroupsPaginator",
+    "DescribeLocalGatewayVirtualInterfacesPaginator",
+    "DescribeLocalGatewaysPaginator",
     "DescribeMovingAddressesPaginator",
     "DescribeNatGatewaysPaginator",
     "DescribeNetworkAclsPaginator",
@@ -408,6 +459,8 @@ __all__ = (
     "DescribeTrafficMirrorSessionsPaginator",
     "DescribeTrafficMirrorTargetsPaginator",
     "DescribeTransitGatewayAttachmentsPaginator",
+    "DescribeTransitGatewayMulticastDomainsPaginator",
+    "DescribeTransitGatewayPeeringAttachmentsPaginator",
     "DescribeTransitGatewayRouteTablesPaginator",
     "DescribeTransitGatewayVpcAttachmentsPaginator",
     "DescribeTransitGatewaysPaginator",
@@ -429,6 +482,7 @@ __all__ = (
     "ExportTaskCompletedWaiter",
     "GetAssociatedIpv6PoolCidrsPaginator",
     "GetTransitGatewayAttachmentPropagationsPaginator",
+    "GetTransitGatewayMulticastDomainAssociationsPaginator",
     "GetTransitGatewayRouteTableAssociationsPaginator",
     "GetTransitGatewayRouteTablePropagationsPaginator",
     "ImageAvailableWaiter",
@@ -442,6 +496,8 @@ __all__ = (
     "NatGatewayAvailableWaiter",
     "NetworkInterfaceAvailableWaiter",
     "PasswordDataAvailableWaiter",
+    "SearchLocalGatewayRoutesPaginator",
+    "SearchTransitGatewayMulticastGroupsPaginator",
     "SecurityGroupExistsWaiter",
     "ServiceResource",
     "SnapshotCompletedWaiter",
